HEADER

biouml.standard.type
Class Diagram type

Dependency Links

to Class Diagram <default>

automatic

to Class Diagram biouml.standard

automatic

to Class Diagram ru.biosoft.access.support

automatic

to Class Diagram biouml.standard.type.access

automatic

to Class Diagram ru.biosoft

automatic

automatic

to Class Diagram ru.biosoft.access

automatic

to Class Diagram ru

automatic
Class Summary
BaseGeneral interface to be implemented by all classes to be used as BioUML diagram elements.
BaseSupportBase class for all data element types.
Biopolymer 
BiopolymerBeanInfoUtility class containing common metada for all molecules.
CellStub
CellBeanInfoUtility class containing common metada for all molecules.
CompartmentStub
CompartmentBeanInfo 
Concept 
ConceptBeanInfo 
ConstantSome constant that can be used in kinetic or other equations.
ConstantBeanInfo 
DatabaseInfoMany data elements can refer to other databases through its database references field.
DatabaseInfoBeanInfo 
DatabaseReferenceGeneral defintion of reference to external database.
DatabaseReferenceBeanInfo 
DiagramInfoDefines common properties for diagram description.
DiagramInfoBeanInfo 
DiagramReference 
EditionHistoryGeneral class defining editing history.
FunctionMolecular function is an activity or task performed by a gene product or other biological entity.
FunctionBeanInfo 
GeneStub
GeneBeanInfo 
GenericEntity 
GenericEntityBeanInfoUtility class containing common metada for all generic entities.
ImageDescriptor 
ImageDescriptorBeanInfo 
KineticLaw 
KineticLawBeanInfoUtility class containing common metada for all generic entities.
KineticTypeDefinition of KinetReactionType defines: - meta information about reaction
KineticTypeBeanInfoUtility class containing common metada for all generic entities.
LiteratureReferenceDefines coomon properties of literature reference.
LiteratureReferenceBeanInfo 
LocalisedString 
MessageBundle 
Molecule 
MoleculeBeanInfoUtility class containing common metada for all molecules.
MultiLineHtmlFieldEditor 
ProcessBiological process is a biological goal that requires more than one function.
ProcessBeanInfo 
ProteinStub
ProteinBeanInfo 
ProteinPropertiesDefines protein properties constants.
Reaction 
ReactionBeanInfo 
ReferrerExtention of GenericEntity that contains references to other databases and literature sources.
ReferrerBeanInfo 
RelationIntermediary class to generalize what is common for all relations/edges as well as to define common constants.
RelationTypeUnit to specify kinetic constat, parameter or variable units.
RNAStub
RNABeanInfo 
SemanticRelationSemanticRelatio specified semantic relationships between concepts (kernels) assotiated with two nodes on the diagram.
SemanticRelationBeanInfo 
SpecieReferenceSpecieReference specifies role of molecule involved in the Reaction.
SpecieReferenceBeanInfo 
SpeciesGeneral definition for 'Species' concept.
SpeciesSpecificGeneral interface for species specific entities.
StateState, stage or variant of biological system or its subunits.
StateBeanInfo 
Stub 
SubstanceStub
SubstanceBeanInfo 
TypeDefinition of data elemnt types (roles).
UnitUnit to specify kinetic constat, parameter or variable units.
UnitBeanInfo 
 


FOOTER

BOTTOM